==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_SEARCHRESULTS","Arama Sonular");
define("_PAGE","Sayfa");
define("_RETURNTO","Geri Dn:");
define("_DEACTIVATE","Pasifletir");
define("_ACTIVATE","Etkinletir");
define("_ENCYCLOPEDIA","Ansiklopedi");
define("_NOCONTENTFORLETTER","zgnm, bu harf iin ierik mevcut deil");
define("_ENCYSELECTLETTER","Terimleri grmek iin ltfen listeden bir harf sein:");
define("_COPYRIGHT","Copyright &copy; $sitename. Tm haklar sakldr.");
define("_YOURADMINENCY","Yneticisiniz, bu ansiklopedi aktif deil!");
define("_ENCYNOTACTIVE","zgnm, bu ansiklopedi u an aktif deil.");
define("_AVAILABLEENCYLIST","Ansiklopedi Listesi:");
define("_YOURADMININACTIVELIST","Yneticisiniz: pasif ansiklopedilerin listesi aadadr:");
define("_NORESULTSTEXT","Terim metninde sonu bulunamad...");
define("_NORESULTSTITLE","Terim balnda sonu bulunamad...");
define("_SEARCHRESULTSFOR","Arama Sonular:");
define("_SEARCHNOTCOMPLETE","Arama seenekleri eksik. Ltfen tekrar deneyin.");
define("_RESULTSINTERMTITLE","Terim balnda sonular:");
define("_RESULTSINTERMTEXT","Terim metninde sonular:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_SEARCHRESULTS","Arama Sonular");
define("_PAGE","Sayfa");
define("_RETURNTO","Geri Dn:");
define("_DEACTIVATE","Pasifletir");
define("_ACTIVATE","Etkinletir");
define("_ENCYCLOPEDIA","Ansiklopedi");
define("_NOCONTENTFORLETTER","zgnm, bu harf iin ierik mevcut deil");
define("_ENCYSELECTLETTER","Terimleri grmek iin ltfen listeden bir harf sein:");
define("_COPYRIGHT","Copyright &copy; $sitename. Tm haklar sakldr.");
define("_YOURADMINENCY","Yneticisiniz, bu ansiklopedi aktif deil!");
define("_ENCYNOTACTIVE","zgnm, bu ansiklopedi u an aktif deil.");
define("_AVAILABLEENCYLIST","Ansiklopedi Listesi:");
define("_YOURADMININACTIVELIST","Yneticisiniz: pasif ansiklopedilerin listesi aadadr:");
define("_NORESULTSTEXT","Terim metninde sonu bulunamad...");
define("_NORESULTSTITLE","Terim balnda sonu bulunamad...");
define("_SEARCHRESULTSFOR","Arama Sonular:");
define("_SEARCHNOTCOMPLETE","Arama seenekleri eksik. Ltfen tekrar deneyin.");
define("_RESULTSINTERMTITLE","Terim balnda sonular:");
define("_RESULTSINTERMTEXT","Terim metninde sonular:");

?>
